<?php
/**
 * PHP Science TextRank (http://php.science/)
 *
 * @see     https://github.com/DavidBelicza/PHP-Science-TextRank
 * @license https://opensource.org/licenses/MIT the MIT License
 * @author  Sezer Fidancı <github.com/SezerFidanci>
 */
declare(strict_types=1);
namespace PhpScience\TextRank\Tool\StopWords;
/**
 * Class Turkish
 *
 * @package PhpScience\TextRank\Tool\StopWords
 */
class Turkish extends StopWordsAbstract
{
    /**
     * Stop words for avoid dummy keywords for Language Turkish.
     * Word list created by Sezer Fidancı.
     * Source: https://raw.githubusercontent.com/abdullahharuntahtali/turkish_stop_words/master/turkish_stopwords.txt
     *
     * @var array
     */
    protected $words = [
        "acaba",
        "aksine",
        "al",
        "alarak",
        "aldılar",
        "aldım",
        "aldırdılar",
        "aldırdım",
        "aldırmadık",
        "aldırmadım",
        "almadım",
        "almaktadır",
        "almıştır",
        "altmış",
        "altı",
        "alıp",
        "ama",
        "amacı",
        "amacında",
        "amacıyla",
        "amaçla",
        "amaçlanmaktadır",
        "an",
        "ancak",
        "anlaşılmaktadır",
        "arada",
        "arasında",
        "artık",
        "asla",
        "aslında",
        "ay",
        "ayrıca",
        "ayrılmaktadır",
        "ayy",
        "az",
        "azdır",
        "bana",
        "bazen",
        "bazı",
        "bazıları",
        "bazısı",
        "başda",
        "başlık",
        "başta",
        "belgelenmiştir",
        "belirlendi",
        "belirlenmiş",
        "belirlenmişdir",
        "belirlenmiştir",
        "belirli",
        "belki",
        "belli",
        "ben",
        "benden",
        "beni",
        "benim",
        "benimde",
        "beri",
        "beş",
        "beşe",
        "beşi",
        "beşinci",
        "beşli",
        "bile",
        "bilhassa",
        "bin",
        "bir",
        "biri",
        "birisi",
        "birkaç",
        "birkaçı",
        "birkez",
        "birlikte",
        "birçok",
        "birçokları",
        "birçoğu",
        "birşey",
        "birşeyi",
        "biz",
        "bizden",
        "bize",
        "bizi",
        "bizim",
        "bu",
        "bulunan",
        "bulunanlar",
        "bulunduk",
        "bulundular",
        "bulundum",
        "bulundunuz",
        "bulunmak",
        "bulunuldu",
        "bulunulmuştur",
        "buna",
        "bunda",
        "bundan",
        "bunlar",
        "bunları",
        "bunların",
        "bunu",
        "bunun",
        "bununda",
        "bununla",
        "burada",
        "böyle",
        "böylece",
        "bütün",
        "ca",
        "ce",
        "çeşitler",
        "çeşitli",
        "çok",
        "çoktur",
        "çoğu",
        "çoğuna",
        "çoğunu",
        "çünkü",
        "da",
        "daa",
        "daha",
        "dahi",
        "dair",
        "de",
        "defa",
        "demek",
        "değil",
        "di",
        "diye",
        "diğer",
        "diğeri",
        "diğerleri",
        "doksan",
        "dokuz",
        "dolayı",
        "dolayısıyla",
        "du",
        "durdu",
        "durduk",
        "durdular",
        "durdum",
        "durulacak",
        "durulacaktır",
        "duruldu",
        "durulmamış",
        "durulmamıştır",
        "durulmuştur",
        "durulur",
        "durulurlar",
        "durumda",
        "durumdur",
        "durunuz",
        "dört",
        "dış",
        "edecek",
        "eden",
        "ederek",
        "edilecek",
        "ediliyor",
        "edilmesi",
        "edilmiş",
        "ediyor",
        "elbette",
        "elli",
        "en",
        "en çok",
        "et",
        "etme",
        "etmedim",
        "etmek",
        "etmekte",
        "etmesi",
        "etti",
        "ettiklerini",
        "ettirmek",
        "ettiği",
        "ettiğini",
        "eğer",
        "fakat",
        "felan",
        "filan",
        "geldiler",
        "gelir",
        "geliyorlar",
        "gelmiş",
        "gelmişler",
        "gene",
        "gerektiğinde",
        "getirdi",
        "getirdik",
        "getirdiler",
        "getirdim",
        "getirdiniz",
        "getirmişler",
        "gibi",
        "gider",
        "gidiyorlar",
        "gil",
        "giller",
        "gine",
        "gitmişler",
        "gittiler",
        "göre",
        "ha",
        "haa",
        "halen",
        "hangi",
        "hangisi",
        "hani",
        "hatta",
        "he",
        "hee",
        "hem",
        "henüz",
        "hep",
        "hepsi",
        "hepsine",
        "hepsini",
        "her",
        "her biri",
        "herhangi",
        "herkes",
        "herkese",
        "herkesi",
        "herkesin",
        "hi",
        "hiç",
        "hiç kimse",
        "hiçbir",
        "hiçbiri",
        "hiçbirine",
        "hiçbirini",
        "hu",
        "huu",
        "hâlâ",
        "hı",
        "ın",
        "ıt",
        "iki",
        "ile",
        "ilgili",
        "in",
        "inceledik",
        "incelediler",
        "incelediniz",
        "incelen",
        "incelendi",
        "incelenmiş",
        "ise",
        "isimiyle",
        "isimle",
        "isimlendirildi",
        "isimlendirilen",
        "isimlendirilmiş",
        "isimli",
        "ismi ile",
        "isminde",
        "isminden",
        "isminin",
        "it",
        "itibaren",
        "itibariyle",
        "içerisi",
        "içerisinde",
        "içerisine",
        "içerisiyle",
        "içersi",
        "için",
        "içinde",
        "işte",
        "kadar",
        "kal",
        "kaldı",
        "kaldık",
        "kaldılar",
        "kaldın",
        "kalır",
        "karşın",
        "katrilyon",
        "kaç",
        "kendi",
        "kendilerine",
        "kendine",
        "kendini",
        "kendisi",
        "kendisine",
        "kendisini",
        "kez",
        "ki",
        "kikir",
        "kikiri",
        "kim",
        "kimden",
        "kime",
        "kimi",
        "kimin",
        "kimisi",
        "kimse",
        "kurulduk",
        "kuruldum",
        "kurulmak",
        "kurulmuştur",
        "kıkır",
        "kırk",
        "la",
        "lar",
        "le",
        "ler",
        "madem",
        "maksadı",
        "maksadı ile",
        "maksadıyla",
        "mi",
        "milyar",
        "milyon",
        "mu",
        "mü",
        "mı",
        "na",
        "nasıl",
        "nda",
        "nde",
        "ndi",
        "ndı",
        "ne",
        "ne kadar",
        "ne zaman",
        "neden",
        "nedenle",
        "nedir",
        "nerde",
        "nerede",
        "nereden",
        "nereye",
        "nesi",
        "neyse",
        "ni",
        "nin",
        "niye",
        "niçin",
        "nu",
        "nü",
        "nı",
        "nın",
        "ol",
        "olan",
        "olanlar",
        "olanların",
        "olarak",
        "oldu",
        "olduk",
        "olduklarını",
        "oldular",
        "oldum",
        "oldun",
        "oldunuz",
        "oldurdu",
        "oldurdular",
        "oldurdun",
        "oldurdunuz",
        "olduğu",
        "olduğunu",
        "olmadı",
        "olmadığı",
        "olmak",
        "olmaktadır",
        "olması",
        "olmayan",
        "olmaz",
        "olsa",
        "olsun",
        "olundu",
        "olundular",
        "olundum",
        "olundun",
        "olup",
        "olur",
        "olursa",
        "oluyor",
        "oluşturmaktadır",
        "on",
        "ona",
        "ondan",
        "onlar",
        "onlara",
        "onlardan",
        "onları",
        "onların",
        "onu",
        "onun",
        "onunda",
        "onunla",
        "orada",
        "ortada",
        "ortadalar",
        "ortadan",
        "ortadayım",
        "ortadayız",
        "ortaya",
        "ortayı",
        "otuz",
        "oysa",
        "oysaki",
        "öbürü",
        "ön",
        "önce",
        "önerdi",
        "önerdiler",
        "önerdim",
        "önerilmiş",
        "önerilmiştir",
        "ötürü",
        "öyle",
        "öze",
        "özü",
        "pek",
        "rağmen",
        "sadece",
        "sana",
        "sanki",
        "saten",
        "sağladığı",
        "sekiz",
        "seksen",
        "sen",
        "senden",
        "seni",
        "senin",
        "seninde",
        "siz",
        "sizden",
        "size",
        "sizi",
        "sizin",
        "son",
        "sonra",
        "sunulmuştur",
        "suretiyle",
        "suretle",
        "söylenebilir",
        "sürece",
        "süretiyle",
        "süretle",
        "sürüldü",
        "sürüldük",
        "sürüldüler",
        "sürüldüm",
        "sürüldünüz",
        "sıfır",
        "sırala",
        "sıraladım",
        "sıralamıştır",
        "şayet",
        "şekilde",
        "şekliyle",
        "şey",
        "şeyden",
        "şeye",
        "şeyi",
        "şeyler",
        "şimdi",
        "şu",
        "şuna",
        "şunda",
        "şundan",
        "şunlar",
        "şunları",
        "şunu",
        "şunun",
        "şununda",
        "şununla",
        "şöyle",
        "ta",
        "taa",
        "tabi",
        "tamam",
        "taraftan",
        "tarafından",
        "tartışılmıştır",
        "te",
        "tee",
        "tir",
        "trilyon",
        "tüm",
        "tümü",
        "tır",
        "ulaştık",
        "ulaştılar",
        "ulaştım",
        "ulaşılan",
        "ulaşıldı",
        "ulaşılmak",
        "ulaşılır",
        "üstlenir",
        "üt",
        "üzere",
        "üzeri",
        "üzerinde",
        "üzerinden",
        "üzerine",
        "üzerinize",
        "üç",
        "var",
        "vardı",
        "ve",
        "veya",
        "veyahut",
        "ya",
        "yaa",
        "yani",
        "yapacak",
        "yapma",
        "yapmak",
        "yaptı",
        "yaptıkları",
        "yaptıklarını",
        "yaptığı",
        "yaptığını",
        "yapılan",
        "yapılması",
        "yapıyor",
        "yararlanılmıştır",
        "ye",
        "yedi",
        "yeniden",
        "yerine",
        "yetmiş",
        "yine",
        "yinemi",
        "yirmi",
        "yla",
        "yle",
        "yoksa",
        "yolla",
        "yolladı",
        "yolladılar",
        "yolladım",
        "yollayalım",
        "yüksektir",
        "yüz",
        "zannetti",
        "zaten",
        "zenberek",
        "zinhar",
    ];
}