<?php
/**
 * Freeform for Craft CMS.
 *
 * @author        Solspace, Inc.
 * @copyright     Copyright (c) 2008-2024, Solspace, Inc.
 *
 * @see           https://docs.solspace.com/craft/freeform
 *
 * @license       https://docs.solspace.com/license-agreement
 */

namespace Solspace\Freeform\Bundles\Notifications\SendListeners;

use Solspace\Freeform\Bundles\Notifications\Providers\NotificationsProvider;
use Solspace\Freeform\Events\Forms\SendNotificationsEvent;
use Solspace\Freeform\Form\Form;
use Solspace\Freeform\Jobs\FreeformQueueHandler;
use Solspace\Freeform\Jobs\SendNotificationsJob;
use Solspace\Freeform\Library\Bundles\FeatureBundle;
use Solspace\Freeform\Notifications\Components\Recipients\Recipient;
use Solspace\Freeform\Notifications\Components\Recipients\RecipientCollection;
use Solspace\Freeform\Notifications\Types\EmailField\EmailField;
use yii\base\Event;

class EmailRecipientNotifications extends FeatureBundle
{
    public function __construct(
        private NotificationsProvider $notificationsProvider,
        private FreeformQueueHandler $queueHandler
    ) {
        Event::on(Form::class, Form::EVENT_SEND_NOTIFICATIONS, [$this, 'sendToRecipients']);
    }

    public function sendToRecipients(SendNotificationsEvent $event): void
    {
        if (!$event->isValid) {
            return;
        }

        $form = $event->getForm();
        if ($form->isDisabled()->emailFieldNotifications) {
            return;
        }

        $notifications = $this->notificationsProvider->getByFormAndClass($form, EmailField::class);
        if (!$notifications) {
            return;
        }

        $fields = $event->getFields();

        foreach ($notifications as $notification) {
            $field = $fields->get($notification->getField());
            if (!$field) {
                continue;
            }

            $recipient = $field->getValue();
            if (!$recipient) {
                continue;
            }

            $notificationTemplate = $notification->getTemplate();
            if (!$notificationTemplate) {
                continue;
            }

            $recipientCollection = new RecipientCollection();
            $recipientCollection->add(new Recipient($recipient));

            $this->queueHandler->executeNotificationJob(
                new SendNotificationsJob([
                    'formId' => $form->getId(),
                    'submissionId' => $event->getSubmission()->getId(),
                    'recipients' => $recipientCollection,
                    'template' => $notificationTemplate,
                ])
            );
        }
    }
}
